#
# spec file for package python-pymavlink
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binaries mavtomfile mavtogpx mavsummarize mavsigloss mavsearch mavplayback mavparms mavparmdiff mavmission mavloss mavlogdump mavlink_bitmask_decoder mavkml mavgraph mavgpslock mavgen mavflighttime mavflightmodes mavfft_isb mavfft mavextract magfit_motors magfit_gps magfit_delta magfit_WMM magfit MPU6KSearch
%bcond_without libalternatives
Name:           python-pymavlink
Version:        2.4.41
Release:        2.1
Summary:        Python MAVLink code
License:        LGPL-3.0-only
URL:            https://github.com/ArduPilot/pymavlink/
Source:         https://files.pythonhosted.org/packages/source/p/pymavlink/pymavlink-%{version}.tar.gz
Patch0:         remove-future-requirement.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-lxml
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module lxml}
# /SECTION
%python_subpackages

%description
A Python library for handling MAVLink protocol streams and log files.
This allows for the creation of simple scripts to analyse telemetry
logs from autopilots such as ArduPilot which use the MAVLink protocol.

%prep
%autosetup -p1 -n pymavlink-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# drop shebang
%python_expand find %{buildroot}%{$python_sitelib} -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;
# FIXME: remove devel files for now
%python_expand rm -rf %{buildroot}%{$python_sitelib}/pymavlink/generator/C
%python_expand rm -rf %{buildroot}%{$python_sitelib}/pymavlink/generator/CPP11
%python_expand rm -rf %{buildroot}%{$python_sitelib}/pymavlink/mavnative/mavlink_defaults.h
# fix spurious exec permissions
%python_expand find %{buildroot}%{$python_sitelib} -name "*.xml" -exec chmod -x '{}' \;
# strip .py file extension from scripts
%python_expand cd %{buildroot}%{_bindir} && find . -name "*.py" -exec sh -c 'mv $0 `basename "$0" .py`' '{}' \;
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_bindir}/$b
done
#
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# remove unneeded files
rm -f %{buildroot}%{_bindir}/_current_flavor

%check
# no tests in PyPI tarball, no tags in upstream repo

%pre
for b in %{binaries}; do
  %python_libalternatives_reset_alternative $b
done

%files %{python_files}
%doc README.md
%python_alternative %{_bindir}/MPU6KSearch
%python_alternative %{_bindir}/magfit
%python_alternative %{_bindir}/magfit_WMM
%python_alternative %{_bindir}/magfit_delta
%python_alternative %{_bindir}/magfit_gps
%python_alternative %{_bindir}/magfit_motors
%python_alternative %{_bindir}/mavextract
%python_alternative %{_bindir}/mavfft
%python_alternative %{_bindir}/mavfft_isb
%python_alternative %{_bindir}/mavflightmodes
%python_alternative %{_bindir}/mavflighttime
%python_alternative %{_bindir}/mavgen
%python_alternative %{_bindir}/mavgpslock
%python_alternative %{_bindir}/mavgraph
%python_alternative %{_bindir}/mavkml
%python_alternative %{_bindir}/mavlink_bitmask_decoder
%python_alternative %{_bindir}/mavlogdump
%python_alternative %{_bindir}/mavloss
%python_alternative %{_bindir}/mavmission
%python_alternative %{_bindir}/mavparmdiff
%python_alternative %{_bindir}/mavparms
%python_alternative %{_bindir}/mavplayback
%python_alternative %{_bindir}/mavsearch
%python_alternative %{_bindir}/mavsigloss
%python_alternative %{_bindir}/mavsummarize
%python_alternative %{_bindir}/mavtogpx
%python_alternative %{_bindir}/mavtomfile
%{python_sitelib}/pymavlink
%{python_sitelib}/pymavlink-%{version}.dist-info

%changelog
* Mon Jun 16 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 2.4.41:
  * mavfft_pid: allow PID target and error frequencies to be
    visualized
  * Fix Wireshark dissector and add snapshot tests
  * tools: added extract_batch_imu.py
  * examples: added dup_samples.py
  * Fix bitshifting issue on 8bit AVR boards when using msgid >
    255 with generated C libs
  * mavgen_c: added XXX_encode_status bindings
  * mavextra: added RotateMag
  * mavutil: Add circle mode for rover
  * DFReader: recognise VER.BU for build type
  * Generator: Lua: allow strings
  * rotmat: added more euler 321 and 312 functions
  * generators: js: fix sinon dependency to 15.2.0, add node
    tests
  * mavutil: fixed multicast on windows
  * tools: fix mavplayback.py
  * sertotcp: auto-reopen serial port
  * Mavgen WLua: Support 64-bit flag fields
  * mavschema - Typo 10E5 should be 1E5
  * tools: Add option to mavgen.py to return exit code if
    generation fails
  * github: test against Python 3.11
  * fixed mavplayback and split
* Tue Sep 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.4.40:
  * Generator: Lua: update to generate script that passes AP's luacheck
  * mavutil.py: add vtol mode mapping
  * add close method to binary reader
  * Split off MissionItemProtocol from WPLoader, use it for fence and rally
  * mavutil: add RTL mode for Blimp
  * generator: add support for relative path to lua mavlink module
  * WLUA - add new port for WSL 18570
  * Fix mavlink Lua Generator for ardupilot lua comments and add it to test
    script
  * mavextra: added earth_accel for bin logs
  * XSD: MAV_CMD missionOnly attribute
  * mavgen_python: Add python3 target with type annotations
  * Use strings for char array mavlink fields again
  * Improve to_string and x25crc
  * gpslag: cope with GPS instances
  * mavextra: updated mag field tables
  * Fix mavutil.mavtcpin not closing the accept()ed port on close()
  * Generator for Ada language
  * mavutil: add force option to reboot_autopilot method
  * mavutil: do not consider MAV_AUTOPILOT_INVALID to be a vehicle heartbeat
  * generator-C: added last_status field for signing
  * Generator C: remove set but not used variable
  * Fix for when signing disabled
  * Fix the format of the output result of mavgen_cs.py
  * mavutil: Return mode as 'Mode(msg.custom_mode)' for high-latency streams
  * mavextra: cope with more Lat/Lon/Lng combinations
  * mavutil: fixed MavlinkSerialPort wrapper for python3
  * generator: lua generator for ardupilot lua scripting
  * tools: add mavmerge to merge two tlogs
  * tools: print progress in magfit_WMM
  * mavutil: do not consider MAV_AUTOPILOT_INVALID to be a vehicle heartbeat
  * mavgen: check for missing enums
  * DFReader: added support for adding new messages to bin logs
  * mavextra: removed cache from earth field calculations
  * schema - Add Ampere-hours units
  * DFReader.py: correct fatal error when stringifying FILE messages
  * mavschema: add nanoseconds
  * mavutil: add DOCK mode to rover
  * mavextra.py: fix average(v, k, N) function
  * mavftpdecode: fixed handling of defaults
  * mavlogdump.py: don't die when handling
  * Disable mavnative by default
  * Tools: Magfit: throttle based
  * DFReader: extract defaults from 4.3.x logs
  * DFReader: fixed defaults handling
  * mavwp: use is_location attribute of WP commands
- Switch to pyproject and autosetup macros.
- Package switched from sitearch to sitelib due to no mavnative
- Stop using globs in %%files
- Add patch remove-future-requirement.patch, dropping future requirement
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.4.35
  * tests: reformat XML
  * mavlogdump.py: don't die when handling bytestrings in dataflash logs
  * mavftpdecode: fixed handling of defaults
  * mavextra.py: fix average(v, k, N) function
  * mavutil: add DOCK mode to rover
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.4.34
  fixed pypi error
* Sun Oct 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.17
  * DFREader: allow ISO-8859-1 as fallback for logs
  * mavfft_isb: allow all HNTCH options to be printed
  * mavgen_python.py: try both tostring and tobytes when checking signature
  * DFReader: use tobytes for py3 in get_msgbuf
  * mavutil: fix docstring typo
  * tools: mavfft_isb add file names to legend for multiple files
  * tools: add axis plot option to mavfft_isb
- Update to version 2.4.16
  * Add Blimp modes
  * mavutil: add new AUTO_RTL mode 27 to copter
  * Tools: magfit_WMM: add option to save plot and param file
  * mavmmaplog: Close the mmap object
  * Update mavlink_signature_check code to be compiler agnostic
  * mavgen_java: Don't hardcode sysid and compid when packing
  * Fix typos discovered by codespell
  * Test on the current versions of Python
  * Fix a typo discovered by codespell
  * Fix typos
  * mavutil: correct parsing of truncated tlogs
  * DFReader.py: fix qnan detection under Python3
  * mavutil.py: update mode mapping for copter
  * added bitmask attribute to MAVEnum
  * build(deps): bump lodash in /generator/javascript_stable
  * build(deps): bump underscore in /generator/javascript
  * build(deps): bump underscore in /generator/javascript_stable
  * build(deps): bump lodash in /generator/javascript
  * Bugfix accessing wrong property
  * mavlogdump: added mode to --meta
  * mavextra: improved distance_two()
  * examples: fixed for gravity
  * Correct magfit_WMM.py to account for AHRS_TRIM
* Wed Apr 28 2021 Markéta Machová <mmachova@suse.com>
- Update to 2.4.15
  * Cross-platform include of endian.h
  * rotmat: added rotation by enum
  * use os.path.abspath() for inlcude files, to allow inlcuding from external folders
  * Generator CS update to support mavlink 2.0
  * mavutil.py: add support for MAV_TYPE_DECAROTOR
  * mavgen: added MAV_IGNORE_CRC for python
  * magfit: fixed for newer scipy versions
  * array.array.fromstring() was removed in Python 3.9
  * tools: Python3 support for mavextract.py
* Fri Aug  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.4.9
  * tools: add mavfft_pid.py to allow FFT analysis for pids in log files
  * Add support for generating Lua 5.3 code for use with ArduPilot
  * make magfit_WMM.py an installable tool
  * few bugfixes
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.4.6
  * mavutil: add separate range check for mavlink2 messages
* Sat Dec 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.2
  * Bugfix release
* Sun Nov 10 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.4.0
